"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var SortDescriptor_1 = require("../models/SortDescriptor");
var SortDirection_1 = require("../enums/SortDirection");
var ts_commons_1 = require("ts-commons");
var class_transformer_1 = require("class-transformer");
var SortHelper = /** @class */ (function () {
    function SortHelper() {
    }
    SortHelper.predicateBySorts = function (obj1, obj2, sorts) {
        var result = 0;
        for (var _i = 0, sorts_1 = sorts; _i < sorts_1.length; _i++) {
            var sort = sorts_1[_i];
            result = this.predicateBySortDescriptorBase(obj1, obj2, sort);
            if (result !== 0) {
                break;
            }
        }
        return result;
    };
    SortHelper.predicateBySortDescriptorBase = function (obj1, obj2, sort) {
        var result = 0;
        if (sort instanceof SortDescriptor_1.SortDescriptor) {
            result = this.predicateBySortDescriptor(obj1, obj2, sort);
        }
        else {
            result = 0;
        }
        return result;
    };
    SortHelper.predicateBySortDescriptor = function (obj1, obj2, SortDescriptor) {
        var propertyPath = SortDescriptor.propertyPath;
        var direction = SortDescriptor.direction;
        var propValue1 = obj1[propertyPath];
        var propValue2 = obj2[propertyPath];
        var result = this.compareTo(direction, propValue1, propValue2);
        return result;
    };
    SortHelper.getRealSorts = function (sorts) {
        if (ts_commons_1.ArrayUtils.isEmpty(sorts)) {
            return [];
        }
        var result = [];
        for (var _i = 0, _a = sorts || []; _i < _a.length; _i++) {
            var filterBase = _a[_i];
            var filterJson = class_transformer_1.serialize(filterBase);
            switch (filterBase.type) {
                case "SortDescriptor":
                    result.push(new SortDescriptor_1.SortDescriptor().fromJSON(filterJson));
                    break;
            }
        }
        return result;
    };
    SortHelper.compareTo = function (direction, value1, value2) {
        var isValue1NullOrUnderfined = ts_commons_1.ObjectUtils.isNullOrUndefined(value1);
        var isValue2NullOrUnderfined = ts_commons_1.ObjectUtils.isNullOrUndefined(value2);
        if (!isValue1NullOrUnderfined && !isValue2NullOrUnderfined) {
            // 当 value1 和 value2 同时有值
            return this.nonNullableCompareTo(direction, value1, value2);
        }
        if (isValue1NullOrUnderfined && isValue2NullOrUnderfined) {
            // 如果两个都是空就是0;
            return 0;
        }
        if (isValue1NullOrUnderfined) {
            return this.value1NullCompareTo(direction);
        }
        else {
            // 2 正好和1 反过来
            return -1 * this.value1NullCompareTo(direction);
        }
    };
    SortHelper.nonNullableCompareTo = function (direction, value1, value2) {
        var result;
        if (value1 === value2) {
            result = 0;
        }
        else if (value1 > value2) {
            result = 1;
        }
        else {
            result = -1;
        }
        switch (direction) {
            case SortDirection_1.SortDirection.ASC:
            case SortDirection_1.SortDirection.ASC_NULL_FIRST:
            case SortDirection_1.SortDirection.ASC_NULL_LAST:
                return result;
            default:
                return -1 * result;
        }
    };
    SortHelper.value1NullCompareTo = function (direction) {
        switch (direction) {
            // null 是最小要放到最上面
            case SortDirection_1.SortDirection.ASC:
            case SortDirection_1.SortDirection.ASC_NULL_FIRST:
            case SortDirection_1.SortDirection.DESC_NULL_FIRST:
                return -1;
            default:
                return 1;
        }
    };
    return SortHelper;
}());
exports.SortHelper = SortHelper;
//# sourceMappingURL=SortHelper.js.map