import { FilterOperator } from "../enums/FilterOperator";
import { BaseFilterDescriptor } from "./BaseFilterDescriptor";
import { ComparableType } from "./ComparableType";
declare type SingleValueOperator = FilterOperator.LESS_THAN | FilterOperator.LESS_THAN_OR_EQUAL | FilterOperator.EQUAL | FilterOperator.NOT_EQUAL | FilterOperator.GREATER_THAN_OR_EQUAL | FilterOperator.GREATER_THAN | FilterOperator.START_WITH | FilterOperator.END_WITH | FilterOperator.CONTAINS | FilterOperator.BITWISE_ANY | FilterOperator.BITWISE_ZERO | FilterOperator.BITWISE_ALL;
declare type CollectionValueOperator = FilterOperator.IN | FilterOperator.NOT_IN | FilterOperator.BETWEEN;
export declare abstract class BaseFilterGroup<T> {
    protected filters: BaseFilterDescriptor<T>[];
    addFilter(filter: BaseFilterDescriptor<T>): this;
    addFilters(filters: BaseFilterDescriptor<T>[]): this;
    removeFilters(filters: BaseFilterDescriptor<T>[]): this;
    getFilters(): BaseFilterDescriptor<T>[];
    and<TProp extends keyof T>(propertyPath: TProp, operator: SingleValueOperator, filterValue: T[TProp] & ComparableType): this;
    and<TProp extends keyof T>(enable: boolean, propertyPath: TProp, operator: SingleValueOperator, filterValue: T[TProp] & ComparableType): this;
    and<TProp extends keyof T>(propertyPath: TProp, operator: CollectionValueOperator, filterValue: Array<T[TProp] & ComparableType>): this;
    and<TProp extends keyof T>(enable: boolean, propertyPath: TProp, operator: CollectionValueOperator, filterValue: Array<T[TProp] & ComparableType>): this;
    and<TProp extends keyof T>(group: (g: BaseFilterGroup<T>) => BaseFilterGroup<T>): this;
    and<TProp extends keyof T>(enable: boolean, group: (g: BaseFilterGroup<T>) => BaseFilterGroup<T>): this;
    or<TProp extends keyof T>(propertyPath: TProp, operator: SingleValueOperator, filterValue: T[TProp] & ComparableType): this;
    or<TProp extends keyof T>(enable: boolean, propertyPath: TProp, operator: SingleValueOperator, filterValue: T[TProp] & ComparableType): this;
    or<TProp extends keyof T>(propertyPath: TProp, operator: CollectionValueOperator, filterValue: Array<T[TProp] & ComparableType>): this;
    or<TProp extends keyof T>(enable: boolean, propertyPath: TProp, operator: CollectionValueOperator, filterValue: Array<T[TProp] & ComparableType>): this;
    or<TProp extends keyof T>(group: (g: BaseFilterGroup<T>) => BaseFilterGroup<T>): this;
    or<TProp extends keyof T>(enable: boolean, group: (g: BaseFilterGroup<T>) => BaseFilterGroup<T>): this;
    private andForFilter;
    private orForFilter;
    private andForFilterGroup;
    private orForFilterGroup;
}
export {};
