"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ts_commons_1 = require("ts-commons");
var FilterCondition_1 = require("../enums/FilterCondition");
var FilterDescriptor_1 = require("./FilterDescriptor");
var FilterGroupDescriptor_1 = require("./FilterGroupDescriptor");
var BaseFilterGroup = /** @class */ (function () {
    function BaseFilterGroup() {
        this.filters = [];
    }
    BaseFilterGroup.prototype.addFilter = function (filter) {
        this.filters.push(filter);
        return this;
    };
    BaseFilterGroup.prototype.addFilters = function (filters) {
        this.filters = this.filters.concat(filters);
        return this;
    };
    BaseFilterGroup.prototype.removeFilters = function (filters) {
        for (var _i = 0, filters_1 = filters; _i < filters_1.length; _i++) {
            var filter = filters_1[_i];
            ts_commons_1.ArrayUtils.remove(this.filters, filter);
        }
        return this;
    };
    BaseFilterGroup.prototype.getFilters = function () {
        return this.filters;
    };
    BaseFilterGroup.prototype.and = function (p1, p2, p3, p4) {
        var p1Type = typeof p1;
        var p2Type = typeof p2;
        var p3Type = typeof p3;
        var p4Type = typeof p4;
        if (p1Type === "boolean" && p2Type === "string" && p3Type === "number") {
            this.andForFilter(p1, p2, p3, p4);
        }
        else if (p1Type === "string" && p2Type === "number") {
            this.andForFilter(true, p1, p2, p3);
        }
        else if (p1Type === "boolean" && p2Type === "function") {
            this.andForFilterGroup(p1, p2);
        }
        else if (p1Type === "function") {
            this.andForFilterGroup(true, p1);
        }
        else {
            throw new TypeError("[ts-dynamic-query.BaseFilterGroup#and] can't resolve type. p1Type: " + p1Type + ", p2Type: " + p2Type + ", p3Type: " + p3Type + ", p4Type: " + p4Type);
        }
        return this;
    };
    BaseFilterGroup.prototype.or = function (p1, p2, p3, p4) {
        var p1Type = typeof p1;
        var p2Type = typeof p2;
        var p3Type = typeof p3;
        var p4Type = typeof p4;
        if (p1Type === "boolean" && p2Type === "string" && p3Type === "number") {
            this.orForFilter(p1, p2, p3, p4);
        }
        else if (p1Type === "string" && p2Type === "number") {
            this.orForFilter(true, p1, p2, p3);
        }
        else if (p1Type === "boolean" && p2Type === "function") {
            this.orForFilterGroup(p1, p2);
        }
        else if (p1Type === "function") {
            this.orForFilterGroup(true, p1);
        }
        else {
            throw new TypeError("[ts-dynamic-query.BaseFilterGroup#or] can't resolve type. p1Type: " + p1Type + ", p2Type: " + p2Type + ", p3Type: " + p3Type + ", p4Type: " + p4Type);
        }
        return this;
    };
    BaseFilterGroup.prototype.andForFilter = function (enable, propertyPath, operator, filterValue) {
        if (enable) {
            var filter = new FilterDescriptor_1.FilterDescriptor();
            filter.propertyPath = propertyPath.toString();
            filter.condition = FilterCondition_1.FilterCondition.AND;
            filter.operator = operator;
            filter.value = filterValue;
            this.addFilter(filter);
        }
    };
    BaseFilterGroup.prototype.orForFilter = function (enable, propertyPath, operator, filterValue) {
        if (enable) {
            var filter = new FilterDescriptor_1.FilterDescriptor();
            filter.propertyPath = propertyPath.toString();
            filter.condition = FilterCondition_1.FilterCondition.OR;
            filter.operator = operator;
            filter.value = filterValue;
            this.addFilter(filter);
        }
    };
    BaseFilterGroup.prototype.andForFilterGroup = function (enable, group) {
        if (enable) {
            var filterGroup = new FilterGroupDescriptor_1.FilterGroupDescriptor();
            filterGroup.condition = FilterCondition_1.FilterCondition.AND;
            group(filterGroup);
            this.addFilter(filterGroup);
        }
    };
    BaseFilterGroup.prototype.orForFilterGroup = function (enable, group) {
        if (enable) {
            var filterGroup = new FilterGroupDescriptor_1.FilterGroupDescriptor();
            filterGroup.condition = FilterCondition_1.FilterCondition.OR;
            group(filterGroup);
            this.addFilter(filterGroup);
        }
    };
    return BaseFilterGroup;
}());
exports.BaseFilterGroup = BaseFilterGroup;
//# sourceMappingURL=BaseFilterGroup.js.map