"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var class_transformer_1 = require("class-transformer");
var FilterHelper_1 = require("../helpers/FilterHelper");
var FilterDescriptor_1 = require("./FilterDescriptor");
var FilterGroupDescriptor_1 = require("./FilterGroupDescriptor");
var SortDescriptor_1 = require("./SortDescriptor");
var ts_commons_1 = require("ts-commons");
var FilterCondition_1 = require("../enums/FilterCondition");
var QueryProvider_1 = require("../providers/QueryProvider");
var SortHelper_1 = require("../helpers/SortHelper");
var BaseFilterGroup_1 = require("./BaseFilterGroup");
var SortDirection_1 = require("../enums/SortDirection");
var DynamicQuery = /** @class */ (function (_super) {
    __extends(DynamicQuery, _super);
    function DynamicQuery() {
        var _this = _super.call(this) || this;
        _this.filters = [];
        _this.sorts = [];
        _this.selectedProperties = [];
        return _this;
    }
    DynamicQuery.createQuery = function (type) {
        var instance = new DynamicQuery();
        instance.type = type;
        return instance;
    };
    DynamicQuery.prototype.addFilterDescriptor = function (option) {
        var filter = new FilterDescriptor_1.FilterDescriptor(option);
        this.filters.push(filter);
        return this;
    };
    DynamicQuery.prototype.addFilterGroupDescriptor = function (option) {
        var filterGroupDescriptor = new FilterGroupDescriptor_1.FilterGroupDescriptor();
        filterGroupDescriptor.condition = ts_commons_1.ObjectUtils.isNullOrUndefined(option.condition)
            ? FilterCondition_1.FilterCondition.AND
            : option.condition;
        for (var _i = 0, _a = option.options; _i < _a.length; _i++) {
            var subOption = _a[_i];
            filterGroupDescriptor.addFilter(new FilterDescriptor_1.FilterDescriptor(subOption));
        }
        this.filters.push(filterGroupDescriptor);
        return this;
    };
    DynamicQuery.prototype.addSort = function (sort) {
        return this.addSorts([sort]);
    };
    DynamicQuery.prototype.addSorts = function (sorts) {
        this.sorts = this.sorts.concat(sorts);
        return this;
    };
    DynamicQuery.prototype.addSortDescriptor = function (sortOption) {
        var sort = new SortDescriptor_1.SortDescriptor(sortOption);
        this.sorts.push(sort);
        return this;
    };
    DynamicQuery.prototype.selectProperty = function (property) {
        var propertyStr = property.toString();
        this.selectedProperties.push(propertyStr);
        return this;
    };
    DynamicQuery.prototype.selectProperties = function () {
        var properties = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            properties[_i] = arguments[_i];
        }
        var propertyStrs = properties.map(function (x) { return x.toString(); });
        this.selectedProperties = this.selectedProperties.concat(propertyStrs);
        return this;
    };
    DynamicQuery.prototype.orderBy = function (propertyPath, direction) {
        return this.addSortDescriptor({
            propertyPath: propertyPath,
            // 默认升序
            direction: ts_commons_1.ObjectUtils.getOrDefault(direction, SortDirection_1.SortDirection.ASC),
        });
    };
    DynamicQuery.prototype.getSorts = function () {
        return this.sorts;
    };
    DynamicQuery.prototype.getSelectedProperties = function () {
        return this.selectedProperties;
    };
    DynamicQuery.prototype.query = function (datas) {
        return QueryProvider_1.QueryProvider.query(datas, this);
    };
    DynamicQuery.prototype.toJSON = function () {
        return class_transformer_1.serialize(this);
    };
    DynamicQuery.prototype.fromJSON = function (json) {
        var obj = class_transformer_1.deserialize(DynamicQuery, json);
        this.filters = FilterHelper_1.FilterHelper.getRealFilters(obj.filters);
        this.sorts = SortHelper_1.SortHelper.getRealSorts(obj.sorts);
        return this;
    };
    return DynamicQuery;
}(BaseFilterGroup_1.BaseFilterGroup));
exports.DynamicQuery = DynamicQuery;
//# sourceMappingURL=DynamicQuery.js.map