"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var FilterOperator_1 = require("../enums/FilterOperator");
var class_transformer_1 = require("class-transformer");
var ts_commons_1 = require("ts-commons");
var FilterCondition_1 = require("../enums/FilterCondition");
/**
 * Initializes a new instance of the FilterDescriptor class.
 */
var FilterDescriptor = /** @class */ (function () {
    function FilterDescriptor(options) {
        this.condition = FilterCondition_1.FilterCondition.AND;
        this.type = "FilterDescriptor";
        this.operator = FilterOperator_1.FilterOperator.EQUAL;
        this.propertyPath = null;
        this.ignoreCase = false;
        this.value = null;
        if (options) {
            this.condition = ts_commons_1.ObjectUtils.isNullOrUndefined(options.condition)
                ? this.condition
                : options.condition;
            this.ignoreCase = ts_commons_1.ObjectUtils.isNullOrUndefined(options.ignoreCase)
                ? this.ignoreCase
                : options.ignoreCase;
            this.operator = options.operator;
            this.value = options.value;
            this.propertyPath = options.propertyPath.toString();
        }
    }
    FilterDescriptor.prototype.getCondition = function () {
        return this.condition;
    };
    /**
     * Serialize current FilterDescriptor to json string.
     */
    FilterDescriptor.prototype.toJSON = function () {
        return class_transformer_1.serialize(this);
    };
    /**
     * Deserialize json string to instance of FilterDescriptor.
     * @param json
     */
    FilterDescriptor.prototype.fromJSON = function (json) {
        var obj = class_transformer_1.deserialize(FilterDescriptor, json);
        this.condition = obj.condition;
        this.operator = obj.operator;
        this.value = obj.value;
        this.ignoreCase = obj.ignoreCase;
        this.propertyPath = obj.propertyPath;
        return this;
    };
    return FilterDescriptor;
}());
exports.FilterDescriptor = FilterDescriptor;
//# sourceMappingURL=FilterDescriptor.js.map